#!/bin/bash

function folder_dialog()
{
  local result=$(osascript << EOT
    tell application "Finder"
      activate
      set fpath to POSIX path of (choose folder)
      return fpath
    end tell
  EOT)

	echo $result
}

# Ask for folder
lib=$(folder_dialog)

if [ ! -d "$lib" ]; then
  echo "🥁 Invalid Kontakt library path"
  read -p "🎹 Press Enter to continue..."
  exit 1
fi

xml=/var/tmp/kontaktLibraryHints.xml

find "$lib" -iname "*.nicnt" -o -iname "*_info.nkx" -type f | while read file
do
  bname=`basename "$file"`

  if [ "$lib/$bname" != "$file" ]; then
    echo "📯 Library ('.nicnt' or '_info.nkx') not found"
    break
  fi

  if [[ "$file" != *.nicnt ]]; then
    ldir=`dirname "$file"`
    hasnicnt=`ls "$ldir" | grep -i '.nicnt' | wc -l`
    if [ $hasnicnt -ne 0 ]; then
      continue
    fi
  fi

  awk '/<ProductHints[ >]/, $NF ~ /<\/ProductHints>/' "$file" | LC_ALL=C sed 's/<\/ProductHints>.*/<\/ProductHints>/' | xmllint --format --recover --encode "UTF-8" - > "$xml"
  name=$(xmllint --xpath "string(//Name)" "$xml")
  regkey=$(xmllint --xpath "string(//RegKey)" "$xml")
  plist="/Library/Preferences/com.native-instruments.$regkey.plist"
  xmldist="/Library/Application Support/Native Instruments/Service Center/$name.xml"

  sudo rm -f "$plist"
  sudo rm -f "$xmldist"
  rm -f "$xml"
done

read -p "🎹 Press Enter to continue..."
